@@ -36,11 +36,7 @@ class AeTmgModelMixin(
         verbose_name = "AE TMG Report"
         verbose_name_plural = "AE TMG Reports"
         indexes = (
-            NonUniqueSubjectIdentifierFieldMixin.Meta.indexes
-            + ActionModelMixin.Meta.indexes
-            + [
-                models.Index(
-                    fields=["subject_identifier", "action_identifier", "site", "id"]
-                )
-            ]
+            *NonUniqueSubjectIdentifierFieldMixin.Meta.indexes,
+            *ActionModelMixin.Meta.indexes,
+            models.Index(fields=["subject_identifier", "action_identifier", "site", "id"]),
         )
