@@ -16,8 +16,6 @@ class BaseBoxItemListboardView(BoxViewMixin, BaseListboardView):
     listboard_view_permission_codename = "edc_lab_dashboard.view_lab_box_listboard"
 
     def get_queryset_filter_options(self, request, *args, **kwargs) -> tuple[Q, dict]:
-        q_object, options = super().get_queryset_filter_options(
-            request, *args, **kwargs
-        )
+        q_object, options = super().get_queryset_filter_options(request, *args, **kwargs)
         options.update({"box": self.box})
         return q_object, {"box": self.box}
