@@ -20,9 +20,7 @@ def delete_receive_items_action(modeladmin, request, queryset: QuerySet[ReceiveI
         messages.add_message(
             request,
             messages.SUCCESS,
-            gettext(
-                f"Successfully deleted {success_count} {ReceiveItem._meta.verbose_name}."
-            ),
+            gettext(f"Successfully deleted {success_count} {ReceiveItem._meta.verbose_name}."),
         )
     if failed_count > 0:
         messages.add_message(
