@@ -12,11 +12,11 @@ class ScreeningMethodsModeMixin(models.Model):
         return f"{self.screening_identifier} {self.gender} {self.age_in_years}"
 
     def natural_key(self: SubjectScreeningModelStub):
-        return (self.screening_identifier,)  # noqa
+        return (self.screening_identifier,)
 
     @staticmethod
     def get_search_slug_fields():
-        return ["screening_identifier", "subject_identifier", "reference"]
+        return "screening_identifier", "subject_identifier", "reference"
 
     @property
     def estimated_dob(self: SubjectScreeningModelStub) -> date:
