@@ -14,16 +14,12 @@ class CrfButton(DashboardModelButton):
 
     @property
     def extra_kwargs(self) -> dict[str, str | int | UUID]:
-        return {
-            self.model_cls().related_visit_model_attr(): self.appointment.related_visit.id
-        }
+        return {self.model_cls().related_visit_model_attr(): self.appointment.related_visit.id}
 
     @property
     def disabled(self) -> str:
         disabled = "disabled"
-        if not self.model_obj and self.perms.add:
-            disabled = ""
-        elif self.perms.change:
+        if (not self.model_obj and self.perms.add) or self.perms.change:
             disabled = ""
         elif self.perms.view:
             if self.model_obj:
